==> zio-aws-codestarconnections_2.12-5.17.104.3-sources.jar: zio/aws/codestarconnections/model/GetConnectionResponse.scala <==
package zio.aws.codestarconnections.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetConnectionResponse(
    connection: Option[zio.aws.codestarconnections.model.Connection] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse = {
    import GetConnectionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
      .builder()
      .optionallyWith(connection.map(value => value.buildAwsValue()))(
        _.connection
      )
      .build()
  }
  def asReadOnly
      : zio.aws.codestarconnections.model.GetConnectionResponse.ReadOnly =
    zio.aws.codestarconnections.model.GetConnectionResponse
      .wrap(buildAwsValue())
}
object GetConnectionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codestarconnections.model.GetConnectionResponse =
      zio.aws.codestarconnections.model
        .GetConnectionResponse(connection.map(value => value.asEditable))
    def connection
        : Option[zio.aws.codestarconnections.model.Connection.ReadOnly]
    def getConnection: ZIO[
      Any,
      AwsError,
      zio.aws.codestarconnections.model.Connection.ReadOnly
    ] = AwsError.unwrapOptionField("connection", connection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
  ) extends zio.aws.codestarconnections.model.GetConnectionResponse.ReadOnly {
    override val connection
        : Option[zio.aws.codestarconnections.model.Connection.ReadOnly] = scala
      .Option(impl.connection())
      .map(value => zio.aws.codestarconnections.model.Connection.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
  ): zio.aws.codestarconnections.model.GetConnectionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codestarconnections_2.13-7.21.15.10-sources.jar: zio/aws/codestarconnections/model/GetConnectionResponse.scala <==
package zio.aws.codestarconnections.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetConnectionResponse(
    connection: Optional[zio.aws.codestarconnections.model.Connection] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse = {
    import GetConnectionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
      .builder()
      .optionallyWith(connection.map(value => value.buildAwsValue()))(
        _.connection
      )
      .build()
  }
  def asReadOnly
      : zio.aws.codestarconnections.model.GetConnectionResponse.ReadOnly =
    zio.aws.codestarconnections.model.GetConnectionResponse
      .wrap(buildAwsValue())
}
object GetConnectionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codestarconnections.model.GetConnectionResponse =
      zio.aws.codestarconnections.model
        .GetConnectionResponse(connection.map(value => value.asEditable))
    def connection
        : Optional[zio.aws.codestarconnections.model.Connection.ReadOnly]
    def getConnection: ZIO[
      Any,
      AwsError,
      zio.aws.codestarconnections.model.Connection.ReadOnly
    ] = AwsError.unwrapOptionField("connection", connection)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
  ) extends zio.aws.codestarconnections.model.GetConnectionResponse.ReadOnly {
    override val connection
        : Optional[zio.aws.codestarconnections.model.Connection.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.connection())
        .map(value => zio.aws.codestarconnections.model.Connection.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codestarconnections.model.GetConnectionResponse
  ): zio.aws.codestarconnections.model.GetConnectionResponse.ReadOnly =
    new Wrapper(impl)
}
